
**Geometric Dynamic Variational Autoencoders (GD-VAE) package** provides machine
learning methods for learning embedding maps for nonlinear dynamics into
general latent spaces. This includes methods for standard latent spaces or
manifold latent spaces with specified geometry and topology. The manifold
latent spaces can be based on analytic expressions or general point cloud
representations.  Package is for use in pytorch.
 
If you find these codes or methods helpful for your project, please cite: 

*GD-VAEs: Geometric Dynamic Variational Autoencoders for 
Learning Non-linear Dynamics and Dimension Reductions,*
R. Lopez and P. J. Atzberger, arXiv:2206.05183, (2022), 
[[arXiv]](http://arxiv.org/abs/2206.05183).

```
@article{lopez_atzberger_gd_vae_2022,
  title={GD-VAEs: Geometric Dynamic Variational Autoencoders for 
  Learning Non-linear Dynamics and Dimension Reductions},
  author={Ryan Lopez, Paul J. Atzberger},
  journal={arXiv:2206.05183},  
  month={June},
  year={2022},
  url={http://arxiv.org/abs/2206.05183}
}
```  

For source code, examples, and additional information see
<https://github.com/gd-vae/gd-vae> and <http://atzberger.org>.

